@@ -52,24 +52,24 @@ class ViewSetMixin(object):
                 "%s/%s/%s%s.html" % (
                     self.manager.base_template_dir,
                     self.manager.template_dir,
-                    ajax,
-                    self.name),
+                    self.name,
+                    ajax),
                 "%s/%s/%s%s.html" % (
                     self.manager.base_template_dir,
                     self.manager.default_app,
-                    ajax,
-                    self.name)
+                    self.name,
+                    ajax)
             ]
         else:
             templates = [
                 "%s/%s%s.html" % (
                     self.manager.template_dir,
-                    ajax,
-                    self.name),
+                    self.name,
+                    ajax),
                 "%s/%s%s.html" % (
                     self.manager.default_app,
-                    ajax,
-                    self.name)
+                    self.name,
+                    ajax)
             ]
         return templates
 
@@ -192,7 +192,7 @@ class ViewSet(object):
     def get_queryset(self, view, request, **kwargs):
         return self.model.objects.all()
 
-    def register(self, name, url=None):
+    def register(self, name, url=None, ordering=0):
         """ use this to decorate your views """
 
         if not url:
@@ -203,6 +203,8 @@ class ViewSet(object):
 
         def inner(view):
             self.views[name] = (view, url)
+            self.views.keyOrder.remove(name)
+            self.views.keyOrder.insert(ordering, name)
             return view
 
         return inner
